import { HttpClient, HttpHeaders } from '@angular/common/http';
import { EventEmitter } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { Observable } from 'rxjs';
import { FieldConfig } from './form/models/field-config.interface';
import { FieldRelation } from './form/models/field-relation.interface';
import { FormConfig } from './form/models/form-config.interface';
import { FieldArithmetic } from './form/models/field-arithmetic.interface';
export declare const VALIDATION_TYPES: {
    required: {
        label: string;
        value: string;
    };
    registerNumber: {
        label: string;
        value: string;
    };
    email: {
        label: string;
        value: string;
    };
    number: {
        label: string;
        value: string;
    };
    url: {
        label: string;
        value: string;
    };
    date: {
        label: string;
        value: string;
    };
    array: {
        label: string;
        value: string;
    };
    json: {
        label: string;
        value: string;
    };
};
export declare const API_TYPES: {
    library: {
        context: string;
        includeToken: boolean;
    };
    location: {
        context: string;
        includeToken: boolean;
    };
    dms: {
        context: string;
        includeToken: boolean;
    };
    file: {
        context: string;
        includeToken: boolean;
    };
};
export declare const SPECIFIC_TYPES: {
    options: {
        value: string;
        label: string;
    }[];
    date: {
        value: string;
        label: string;
    }[];
    file: {
        value: string;
        label: string;
    }[];
};
export declare const CONTAINER_TYPES: {
    title: string;
    id: string;
    icon: string;
    name: string;
}[];
export declare const STEP_TYPES: {
    title: string;
    id: string;
    icon: string;
    name: string;
    description: string;
}[];
export declare const REVIEW_STATUS_TYPES: {
    id: string;
    color: string;
    title: string;
    action: string;
}[];
export declare const STATUS_TYPES: {
    id: string;
    color: string;
    title: string;
    action: string;
    declinedTxt: string;
    approvedTxt: string;
    declinedFinishTxt: string;
    approvedFinishTxt: string;
    returnStatus: any;
    declinedAction: string;
    approvedAction: string;
}[];
export declare const BUTTON_TYPES: {
    type: string;
    title: string;
    id: string;
    icon: string;
    name: string;
}[];
export declare const FIELD_TYPES: ({
    value: string;
    icon: string;
    name: string;
    specificTypes?: undefined;
    validations?: undefined;
    apiOptions?: undefined;
} | {
    value: string;
    name: string;
    icon: string;
    specificTypes: {
        value: string;
        label: string;
    }[];
    validations: {
        label: string;
        value: string;
    }[];
    apiOptions?: undefined;
} | {
    value: string;
    icon: string;
    name: string;
    apiOptions: {
        context: string;
        includeToken: boolean;
    };
    specificTypes: {
        value: string;
        label: string;
    }[];
    validations?: undefined;
} | {
    value: string;
    name: string;
    icon: string;
    validations: {
        label: string;
        value: string;
    }[];
    specificTypes?: undefined;
    apiOptions?: undefined;
})[];
export declare const RELATION: {
    action: {
        value: string;
        label: string;
    }[];
    connective: {
        value: string;
        label: string;
    }[];
    condition: {
        value: string;
        label: string;
    }[];
    when: any[];
};
export declare const ARITHMETIC: {
    action: {
        value: string;
        label: string;
    }[];
};
export declare class NgxDynamicTagService {
    config: any;
    protected http: HttpClient;
    libraries: any[];
    locations: any[];
    onQuarterSelect: EventEmitter<any>;
    exportSubscription: EventEmitter<any>;
    private dateFormat;
    constructor(config: any, http: HttpClient);
    containers(): {
        title: string;
        id: string;
        icon: string;
        name: string;
    }[];
    steps(): {
        title: string;
        id: string;
        icon: string;
        name: string;
        description: string;
    }[];
    statuses(): {
        id: string;
        color: string;
        title: string;
        action: string;
        declinedTxt: string;
        approvedTxt: string;
        declinedFinishTxt: string;
        approvedFinishTxt: string;
        returnStatus: any;
        declinedAction: string;
        approvedAction: string;
    }[];
    buttons(): {
        type: string;
        title: string;
        id: string;
        icon: string;
        name: string;
    }[];
    fields(): ({
        value: string;
        icon: string;
        name: string;
        specificTypes?: undefined;
        validations?: undefined;
        apiOptions?: undefined;
    } | {
        value: string;
        name: string;
        icon: string;
        specificTypes: {
            value: string;
            label: string;
        }[];
        validations: {
            label: string;
            value: string;
        }[];
        apiOptions?: undefined;
    } | {
        value: string;
        icon: string;
        name: string;
        apiOptions: {
            context: string;
            includeToken: boolean;
        };
        specificTypes: {
            value: string;
            label: string;
        }[];
        validations?: undefined;
    } | {
        value: string;
        name: string;
        icon: string;
        validations: {
            label: string;
            value: string;
        }[];
        specificTypes?: undefined;
        apiOptions?: undefined;
    })[];
    icons(): string[];
    relation(): {
        action: {
            value: string;
            label: string;
        }[];
        connective: {
            value: string;
            label: string;
        }[];
        condition: {
            value: string;
            label: string;
        }[];
        when: any[];
    };
    arithmetic(): {
        action: {
            value: string;
            label: string;
        }[];
    };
    fromJSON(inputJson: any, buttons?: any[]): {
        submitOnEnter: any;
        groups: any[];
    };
    fromGroupJson(group: any): {
        layout: any;
        toggle: any;
        toggled: any;
        legend: any;
        button: any;
        rows: any[];
    };
    map(values: any, hasIcon?: boolean): any[];
    clone(data: any): any;
    isValidControl(form: FormGroup, control: string, submitted: boolean): boolean;
    isTouchedControl(form: FormGroup, control: string): boolean;
    getErrors(form: FormGroup, control: string): any;
    getTrimmedValue(value: any): any;
    getDateFormat(): string;
    getConfigField(config: FormConfig, name: string): FieldConfig;
    getConfigFieldBy(config: FormConfig, name: string, type: string): FieldConfig;
    getConfigArithmetic(config: FormConfig, element: string): FieldArithmetic;
    getConfigRelation(config: FormConfig, element: string): FieldRelation;
    getConfigFieldByProp(config: FormConfig, element: string, field: string, value?: any): any;
    library(name: any): Promise<{}>;
    dmscode(locationId: any): Promise<{}>;
    getArcgisToken(): Promise<{}>;
    location(parentId: any): Promise<{}>;
    upload(options: any, data: any): Observable<Object>;
    get(url: string, token: boolean): Observable<Object>;
    post(url: string, data: any, token: boolean): Observable<Object>;
    getToken(token: string): string;
    protected getCDNHeader(token: boolean): {
        headers: HttpHeaders;
    };
    protected getHeader(token: boolean): {
        headers: HttpHeaders;
    };
}
